==> kde4pim_3.92.0.orig.tar.gz: kdepim-3.92.0/libkleo/backends/qgpgme/qgpgmedeletejob.cpp <==
/*
    qgpgmedeletejob.cpp

    This file is part of libkleopatra, the KDE keymanagement library
    Copyright (c) 2004 Klarälvdalens Datakonsult AB

    Libkleopatra is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation; either version 2 of the
    License, or (at your option) any later version.

    Libkleopatra is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License along
    with this program; if not, write to the Free Software Foundation, Inc.,
    51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA

    In addition, as a special exception, the copyright holders give
    permission to link the code of this program with any edition of
    the Qt library by Trolltech AS, Norway (or with modified versions
    of Qt that use the same license as Qt), and distribute linked
    combinations including the two.  You must obey the GNU General
    Public License in all respects for all of the code used other than
    Qt.  If you modify this file, you may extend this exception to
    your version of the file, but you are not obligated to do so.  If
    you do not wish to do so, delete this exception statement from
    your version.
*/

#include "qgpgmedeletejob.h"

#include <qgpgme/eventloopinteractor.h>

#include <gpgme++/context.h>

#include <assert.h>

Kleo::QGpgMEDeleteJob::QGpgMEDeleteJob( GpgME::Context * context )
  : DeleteJob( QGpgME::EventLoopInteractor::instance(), "Kleo::QGpgMEDeleteJob" ),
    QGpgMEJob( this, context )
{
  assert( context );
}

Kleo::QGpgMEDeleteJob::~QGpgMEDeleteJob() {
}

GpgME::Error Kleo::QGpgMEDeleteJob::start( const GpgME::Key & key, bool allowSecretKeyDeletion ) {

  hookupContextToEventLoopInteractor();

  const GpgME::Error err = mCtx->startKeyDeletion( key, allowSecretKeyDeletion );

  if ( err )
    deleteLater();
  return err;
}

void Kleo::QGpgMEDeleteJob::doOperationDoneEvent( const GpgME::Error & error ) {
  emit result( error );
}

#include "qgpgmedeletejob.moc"

==> kde4pim_3.94.0.orig.tar.gz: kdepim-3.94.0/libkleo/backends/qgpgme/qgpgmedeletejob.cpp <==
/*
    qgpgmedeletejob.cpp

    This file is part of libkleopatra, the KDE keymanagement library
    Copyright (c) 2004 Klarälvdalens Datakonsult AB

    Libkleopatra is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation; either version 2 of the
    License, or (at your option) any later version.

    Libkleopatra is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License along
    with this program; if not, write to the Free Software Foundation, Inc.,
    51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA

    In addition, as a special exception, the copyright holders give
    permission to link the code of this program with any edition of
    the Qt library by Trolltech AS, Norway (or with modified versions
    of Qt that use the same license as Qt), and distribute linked
    combinations including the two.  You must obey the GNU General
    Public License in all respects for all of the code used other than
    Qt.  If you modify this file, you may extend this exception to
    your version of the file, but you are not obligated to do so.  If
    you do not wish to do so, delete this exception statement from
    your version.
*/

#include "qgpgmedeletejob.h"

#include <qgpgme/eventloopinteractor.h>

#include <gpgme++/context.h>

#include <assert.h>

Kleo::QGpgMEDeleteJob::QGpgMEDeleteJob( GpgME::Context * context )
  : DeleteJob( QGpgME::EventLoopInteractor::instance() ),
    QGpgMEJob( this, context )
{
  assert( context );
}

Kleo::QGpgMEDeleteJob::~QGpgMEDeleteJob() {
}

GpgME::Error Kleo::QGpgMEDeleteJob::start( const GpgME::Key & key, bool allowSecretKeyDeletion ) {

  hookupContextToEventLoopInteractor();

  const GpgME::Error err = mCtx->startKeyDeletion( key, allowSecretKeyDeletion );

  if ( err )
    deleteLater();
  return err;
}

void Kleo::QGpgMEDeleteJob::doOperationDoneEvent( const GpgME::Error & error ) {
  emit result( error );
}

#include "qgpgmedeletejob.moc"
